#
# spec file for package python3-kombu
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python3-kombu
Version:        3.0.35
Release:        1.2
Summary:        AMQP Messaging Framework for Python
License:        BSD-3-Clause
Group:          Development/Languages/Python
Url:            http://github.com/celery/kombu/
Source:         https://files.pythonhosted.org/packages/source/k/kombu/kombu-%{version}.tar.gz
BuildRequires:  python3-devel
BuildRequires:  python3-setuptools
BuildRequires:  python3-amqp >= 1.0.13
BuildRequires:  python3-amqplib
# Test requirements:
# BuildRequires:  python3-PyYAML
# BuildRequires:  python3-anyjson >= 0.3.3
# BuildRequires:  python3-mock
# BuildRequires:  python3-nose-cover3
# BuildRequires:  python3-unittest2 >= 0.5.0
Requires:       python3-amqp >= 1.0.13
Requires:       python3-anyjson >= 0.3.3
Recommends:     couchdb
Recommends:     mongodb
Recommends:     rabbitmq-server
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch

%description
An AMQP messaging framework for Python.

AMQP is the Advanced Message Queuing Protocol, an open standard protocol
for message orientation, queuing, routing, reliability and security.

One of the most popular implementations of AMQP is RabbitMQ.

The aim of Kombu is to make messaging in Python as easy as possible by
providing an idiomatic high-level interface for the AMQP protocol, and also
provide proven and tested solutions to common messaging problems.

%prep
%setup -q -n kombu-%{version}
# For rpmlint warning: remove shebang from python library:
sed -i '/^#!/d' ./kombu/tests/test_serialization.py
# TODO(saschpe): Stop dropping this test once upstream finalized Py3K support:
rm kombu/tests/transport/test_filesystem.py kombu/tests/utils/test_encoding.py
2to3 -wvn .

%build
python3 setup.py build

%install
python3 setup.py install --prefix=%{_prefix} --root=%{buildroot}

# Tests are currently incompatible with latest amqp.  Check in next release.
# %check
# python3 setup.py test

%files
%defattr(-,root,root,-)
%doc AUTHORS Changelog FAQ README.rst THANKS TODO LICENSE
%{python3_sitelib}/kombu
%{python3_sitelib}/kombu-%{version}-py%{py3_ver}.egg-info

%changelog
* Mon Jun 13 2016 toddrme2178@gmail.com
- Comment out unused test requirements.
* Sun May  8 2016 arun@gmx.de
- specfile:
  * changed to https for source url
  * updated source url to files.pythonhosted.org
* Sat Mar 26 2016 arun@gmx.de
- update to version 3.0.35:
  * msgpack: msgpack support now requires msgpack-python > 0.4.7.
  * Redis: TimeoutError was no longer handled as a recoverable error.
  * Redis: Adds the ability to set more Redis connection options using
    "Connection(transport_options={...})".
    + "socket_connect_timeout"
    + "socket_keepalive" (requires :mod:`redis-py` > 2.10)
    + "socket_keepalive_options" (requires :mod:`redis-py` > 2.10)
  * msgpack: Fixes support for binary/unicode data
* Tue Mar 15 2016 toddrme2178@gmail.com
- Remove unneeded python3-PyMongo buildrequires.
  It was preventing building on big-endian architectures.
* Sat Mar  5 2016 arun@gmx.de
- update to version 3.0.34:
  * Qpid: Adds async error handling.  Contributed by Brian Bouterse.
  * Qpid: Delivery tag is now a UUID4 (Issue #563).  Fix contributed
    by Brian Bouterse.
  * Redis: Connection.as_uri() returned malformed URLs when the
    "redis+socket" scheme was ised (Issue celery/celery#2995).
  * msgpack: Use binary encoding instead of utf-8 (Issue #570).
* Wed Jan 27 2016 arun@gmx.de
- specfile:
  * update copyright year
- update to version 3.0.33:
  * Now depends on :mod:`amqp` 1.4.9.
  * Redis: Fixed problem with auxilliary connections causing the main
    consumer connection to be closed (Issue #550).
  * Qpid: No longer uses threads to operate, to ensure compatibility
    with all environments (Issue #531).
- changes from version 3.0.32:
  * Redis: Fixed bug introduced in 3.0.31 where the redis transport
    always connects to localhost, regardless of host setting.
- changes from version 3.0.31:
  * Redis: Fixed bug introduced in 3.0.30 where socket was prematurely
    disconnected.
  * Hub: Removed debug logging message: "Deregistered fd..." (Issue
    [#549]).
- changes from version 3.0.30:
  * Fixes compatiblity with uuid in Python 2.7.11 and 3.5.1. Fix
    contributed by Kai Groner.
  * Redis transport: Attempt at fixing problem with hanging consumer
    disconnected from server.
  * Event loop: Attempt at fixing issue with 100%% CPU when using the
    Redis transport,
  * Database transport: Fixed oracle compatiblity. An "ORA-00907:
    missing right parenthesis" error could manifest when using an
    Oracle database with the database transport.  Fix contributed by
    Deepak N.
  * Documentation fixes Contributed by Tommaso Barbugli.
* Thu Oct 29 2015 arun@gmx.de
- update to version 3.0.29:
  * Fixed serialization issue for "bindings.as_dict()" (Issue #453).
    Fix contributed by Sergey Tikhonov.
  * Json serializer wrongly treated bytes as "ascii", not "utf-8"
    (Issue #532).
  * MongoDB: Now supports pymongo 3.x.
    Contributed by Len Buckens.
  * SQS: Tests passing on Python 3.
    Fix contributed by Felix Yan
* Sat Oct 17 2015 arun@gmx.de
- update to version 3.0.28:
  * No longer compatible with South by default.
  * Keep old South migrations in "kombu.south.migrations".
  * Now works with Redis < 2.10 again.
- changes from version 3.0.27:
  * Now depends on :mod:`amqp` 1.4.7.
  * Fixed libSystem import error on some OS X 10.11 (El Capitan)
    installations.  Fix contributed by Eric Wang.
  * Now compatible with Django 1.9.
  * Django: Adds migrations for the database transport.
  * Redis: Now depends on py-redis 2.10.0 or later (Issue #468).
  * QPid: Can now connect as localhost (Issue #519).  Fix contributed
    by Brian Bouterse.
  * QPid: Adds support for "login_method" (Issue #502, Issue #499).
    Contributed by Brian Bouterse.
  * QPid: Now reads SASL mechanism from broker string (Issue #498).
    Fix contributed by Brian Bouterse.
  * QPid: Monitor thread now properly terminated on session close
    (Issue #485).  Fix contributed by Brian Bouterse.
  * QPid: Fixed file descriptor leak (Issue #476).  Fix contributed by
    Jeff Ortel
  * Docs: Fixed wrong order for entrypoint arguments (Issue #473).
  * ConsumerMixin: Connection error logs now include traceback (Issue
    [#480]).
  * BaseTransport now raises RecoverableConnectionError when
    disconnected (Issue #507).
  * Consumer: Adds "tag_prefix" option to modify how consumer tags are
    generated (Issue #509).
* Sat Apr 25 2015 arun@gmx.de
- update to version 3.0.26:
  * Fixed compatibility with py-redis versions before 2.10.3 (Issue
    [#470]).
- changes from version 3.0.25:
  * pyamqp/librabbitmq now uses 5671 as default port when SSL is
    enabled (Issue #459).
  * Redis: Now supports passwords in "redis+socket://:pass@host:port"
    URLs (Issue #460).
  * "Producer.publish" now defines the "expiration" property in
    support of the `RabbitMQ per-message TTL extension`_.  Contributed
    by Anastasis Andronidis.
  * Connection transport attribute now set correctly for all
    transports.  Contributed by Alex Koshelev.
  * qpid: Fixed bug where the connectionw as not being closed
    properly.  Contributed by Brian Bouterse.
  * :class:`~kombu.entity.bindings` is now JSON serializable (Issue
    [#453]).  Contributed by Sergey Tikhonov.
  * Fixed typo in error when yaml is not installed (said "msgpack").
    Contributed by Joshua Harlow.
  * Redis: Now properly handles "TimeoutError raised by py-redis.
    Contributed by markow.
  * qpid: Adds additional string to check for when connecting to qpid.
    When we connect to qpid, we need to ensure that we skip to the
    next SASL mechanism if the current mechanism fails. Otherwise, we
    will keep retrying the connection with a non-working mech.
    Contributed by Chris Duryee.
  * qpid: Handle "NotFound" exceptions.  Contributed by Brian
    Bouterse.
  * :class:`Queue.__repr__` now makes sure return value is not unicode
    (Issue #440).
  * qpid: "Queue.purge" incorrectly raised :exc:`AttributeErrror` if
    the does not exist (Issue #439).  Contributed by Brian Bouterse.
  * Linux: Now ignores permission errors on epoll unregister.
* Sat Jan 10 2015 arun@gmx.de
- specfile:
  * remove ifs for opensuse version <=1220
* Sat Jan 10 2015 arun@gmx.de
- specfile:
  * update copyright year
  * update url
- update to version 3.0.24:
  * The 'Qpid <http://qpid.apache.org/>' broker is supported for
    Python 2.x environments. The Qpid transport includes full SSL
    support within Kombu. See the 'kombu.transport.qpid' docs for more
    info.  Contributed by Brian Bouterse and Chris Duryee through
    support from Red Hat.
  * Dependencies: extra[librabbitmq] now requires librabbitmq 1.6.0
  * Docstrings for '~kombu.utils.limit.TokenBucket' did not match
    implementation.  Fix contributed by Jesse Dhillon.
  * '~kombu.common.oid_from' accidentally called "uuid.getnode()" but
    did not use the return value.  Fix contributed by Alexander
    Todorov.
  * Redis: Now ignores errors when cosing the underlying connection.
  * Redis: Restoring messages will now use a single connection.
  * "kombu.five.monotonic": Can now be imported even if ctypes is not
    available for some reason (e.g. App Engine)
  * Documentation: Improved example to use the "declare" argument to
    "Producer" (Issue #423).
  * Django: Fixed "app_label" for older Django versions ("< 1.7").
    (Issue #414).
- changes from version 3.0.23:
  * Django: Fixed bug in the Django 1.7 compatibility improvements
    related to autocommit handling.  Contributed by Radek Czajka.
  * Django: The Django transport models would not be created on syncdb
    after app label rename (Issue #406).
- changes from version 3.0.22:
  * kombu.async: Min. delay between waiting for timer was always
    increased to one second.
  * Fixed bug in itermessages where message is received after the with
    statement exits the block.  Fixed by Rumyana Neykova
  * Connection.autoretry: Now works with functions missing wrapped
    attributes ("__module__", "__name__", "__doc__"). Fixes #392.
    Contributed by johtso.
  * Django: Now sets custom app label for "kombu.transport.django" to
    work with recent changes in Django 1.7.
  * SimpleQueue removed messages from the wrong end of buffer (Issue
    [#380]).
  * Tests: Now using "unittest.mock" if available (Issue #381).
- changes from version 3.0.21:
  * Fixed remaining bug in "maybe_declare" for "auto_delete"
    exchanges.  Fix contributed by Roger Hu.
  * MongoDB: Creating a channel now properly evaluates a connection
    (Issue #363).  Fix contributed by Len Buckens.
* Wed Jun 25 2014 i@marguerite.su
- update version 3.0.20
  * Reverts change in 3.0.17 where ``maybe_declare`` caches
    the declaration of auto_delete queues and exchanges.
  * Redis: Fixed race condition when using gevent and the
    channel is closed.
- temporary disable checks. needed more packages update
* Wed Oct 23 2013 toddrme2178@gmail.com
- Disable non-working tests on openSUSE 12.2
* Thu Aug 15 2013 speilicke@suse.com
- Update to version 2.5.14:
  + safe_str did not work properly resulting in
    UnicodeDecodeError (Issue #248).
- Changes from version 2.5.13:
  + Now depends on amqp 1.0.13
  + Fixed typo in Django functional tests.
  + safe_str now returns Unicode in Python 2.x
  + amqp: Transport options are now merged with arguments
    supplied to the connection.
  + Tests no longer depends on distribute, which was deprecated
    and merged back into setuptools.
  + ConsumerMixin now also restarts on channel related errors.
- Changes from version 1.0.12:
  + Redis: Ignore errors about keys missing in the round-robin cycle.
  + Fixed test suite errors on Python 3.
  + Fixed msgpack test failures.
  + librabbitmq: Fixed a cyclic reference at connection close.
  + Now depends on amqp 1.0.12 (Py3 compatibility issues).
* Thu Jul 18 2013 cfarrell@suse.com
- license update: BSD-3-Clause
  See LICENSE (also consider checking the license of the python 2 package)
* Tue Jul 16 2013 speilicke@suse.com
- Run 2to3
* Tue Apr 30 2013 speilicke@suse.com
- Expanded test coverage
- Don't require python-msgpack-python for testing until issues are fixed.
  It's an optional feature anyway
- Drop link to python3-kombu, it's not really support Py3K ATM
* Fri Apr 12 2013 alexandre@exatati.com.br
- Update to 2.5.10:
  Kombu 3 consumers will no longer accept pickle/yaml or msgpack
  by default, and you will have to explicitly enable untrusted deserializers
  either globally using kombu.enable_insecure_serializers, or
  using the accept argument to kombu.Consumer.
  - New utility function to disable/enable untrusted serializers.
  - kombu.disable_insecure_serializers
  - kombu.enable_insecure_serializers
  - Consumer: `accept` can now be used to specify a whitelist
    of content types to accept.
    If the accept whitelist is set and a message is received
    with a content type that is not in the whitelist then a
    :exc:`~kombu.exceptions.ContentDisallowed` exception
    is raised.  Note that this error can be handled by the already
    existing `on_decode_error` callback
    Examples:
    Consumer(accept=['application/json'])
    Consumer(accept=['pickle', 'json'])
  - Now depends on amqp 1.0.11
  - pidbox: Mailbox now supports the `accept` argument.
  - Redis: More friendly error for when keys are missing.
  - Connection URLs: The parser did not work well when there were
    multiple '+' tokens.
- Remove patch that is no longer needed
* Fri Apr 12 2013 toddrme2178@gmail.com
- Change suggests to recommends since suggests are not well supported
- Disable simplejson on openSUSE <= 12.2 since it is not supported
* Thu Apr 11 2013 alexandre@exatati.com.br
- Update to 2.5.9:
  - Pidbox: Now warns if there are multiple nodes consuming from
    the same pidbox.
  - Adds Queue.on_declared <kombu.Queue.on_declared>
    A callback to be called when the queue is declared,
    with signature (name, messages, consumers).
  - Now uses fuzzy matching to suggest alternatives to typos in transport
    names.
  - SQS: Adds new transport option queue_prefix.
    Contributed by j0hnsmith.
  - pyamqp: No longer overrides verify_connection.
  - SQS: Now specifies the driver_type and driver_name
    attributes.
    Fix contributed by Mher Movsisyan.
  - Fixed bug with kombu.utils.retry_over_time when no errback
    specified.
* Thu Mar 21 2013 alexandre@exatati.com.br
- Update to 2.5.8:
  - Now depends on amqp 1.0.10 which fixes a Python 3 compatibility
    error.
  - Redis: Fixed a possible race condition (Issue #171).
  - Redis: Ack emulation/visibility_timeout can now be disabled
    using a transport option.
    Ack emulation adds quite a lot of overhead to ensure data is safe
    even in the event of an unclean shutdown.  If data loss do not worry
    you there is now an `ack_emulation` transport option you can use
    to disable it:
    Connection('redis://', transport_options={'ack_emulation': False})
  - SQS: Fixed boto v2.7 compatibility (Issue #207).
  - Exchange: Should not try to re-declare default exchange ("")
    (Issue #209).
  - SQS: Long polling is now disabled by default as it was not
    implemented correctly, resulting in long delays between receiving
    messages (Issue #202).
  - Fixed Python 2.6 incompatibility depending on exc.errno
    being available.
    Fix contributed by Ephemera.
* Fri Mar  8 2013 alexandre@exatati.com.br
- Update to 2.5.7:
  - Now depends on amqp 1.0.9
  - Redis: A regression in 2.5.6 caused the redis transport to
    ignore options set in transport_options.
  - Redis: New socket_timeout transport option.
  - Redis: InconsistencyError is now regarded as a recoverable error.
  - Resource pools: Will no longer attempt to release resource
    that was never acquired.
  - MongoDB: Now supports the ssl option.
    Contributed by Sebastian Pawlus.
* Thu Feb  7 2013 alexandre@exatati.com.br
- Update to 2.5.5:
  SQS: Now supports long polling (Issue #176).
    The polling interval default has been changed to 0 and a new
    transport option (wait_time_seconds) has been added.
    This parameter specifies how long to wait for a message from
    SQS, and defaults to 20 seconds, which is the maximum
    value currently allowed by Amazon SQS.
    Contributed by James Saryerwinnie.
  - SQS: Now removes unpickleable fields before restoring messages.
  - Consumer.__exit__ now ignores exceptions occurring while
    cancelling the consumer.
  - Virtual:  Routing keys can now consist of characters also used
    in regular expressions (e.g. parens) (Issue #194).
  - Virtual: Fixed compression header when restoring messages.
    Fix contributed by Alex Koshelev.
  - Virtual: ack/reject/requeue now works while using basic_get.
  - Virtual: Message.reject is now supported by virtual transports
    (requeue depends on individual transport support).
  - Fixed typo in hack used for static analyzers.
    Fix contributed by Basil Mironenko.
* Thu Jan 17 2013 alexandre@exatati.com.br
- Add LICENSE file to %%doc.
* Mon Jan 14 2013 saschpe@suse.de
- Drop build requires on python3-2to3, it's in python3-devel now
- Don't require "python(abi)", RPM does that automatically
* Fri Jan 11 2013 p.drouand@gmail.com
- Initial python3 support
- Fix rpmlint shebang warning for test_serialization.py
